@@ -4,3 +4,6 @@
    :mod:`migrate.changeset` that allows to define database schema changes
    using Python.
 """
+
+from migrate.versioning import *
+from migrate.changeset import *
