@@ -1,16 +1,21 @@
 """
    Oracle database specific implementations of changeset classes.
 """
-
-from migrate.changeset import ansisql, exceptions
-from sqlalchemy.databases import oracle as sa_base
 import sqlalchemy as sa
 
-OracleSchemaGenerator = sa_base.OracleSchemaGenerator
+from migrate.changeset import ansisql, exceptions
+
+from sqlalchemy.databases import oracle as sa_base
+
+from migrate.changeset import ansisql, exceptions, SQLA_06
+
+if not SQLA_06:
+    OracleSchemaGenerator = sa_base.OracleSchemaGenerator
+else:
+    OracleSchemaGenerator = sa_base.OracleDDLCompiler
 
 
-class OracleColumnGenerator(OracleSchemaGenerator,
-                            ansisql.ANSIColumnGenerator):
+class OracleColumnGenerator(OracleSchemaGenerator, ansisql.ANSIColumnGenerator):
     pass
 
 
@@ -34,24 +39,21 @@ class OracleSchemaChanger(OracleSchemaGenerator, ansisql.ANSISchemaChanger):
 
     def visit_column(self, delta):
         keys = delta.keys()
-        if 'type' in keys or 'nullable' in keys or 'default' in keys \
-                or 'server_default' in keys:
-            self._run_subvisit(delta, self._visit_column_change)
+
         if 'name' in keys:
-            self._run_subvisit(delta, self._visit_column_name)
+            self._run_subvisit(delta,
+                               self._visit_column_name,
+                               start_alter=False)
 
-    def _visit_column_change(self, table_name, col_name, delta):
-        if not hasattr(delta, 'result_column'):
-            # Oracle needs the whole column definition, not just a
-            # lone name/type
-            raise exceptions.NotSupportedError(
-                "A column object is required to do this")
+        if len(set(('type', 'nullable', 'server_default')).intersection(keys)):
+            self._run_subvisit(delta,
+                               self._visit_column_change,
+                               start_alter=False)
 
-        column = delta.result_column
+    def _visit_column_change(self, table, column, delta):
         # Oracle cannot drop a default once created, but it can set it
         # to null.  We'll do that if default=None
-        # http://forums.oracle.com/forums/message.jspa?\
-        # messageID=1273234#1273234
+        # http://forums.oracle.com/forums/message.jspa?messageID=1273234#1273234
         dropdefault_hack = (column.server_default is None \
                                 and 'server_default' in delta.keys())
         # Oracle apparently doesn't like it when we say "not null" if
@@ -67,8 +69,8 @@ class OracleSchemaChanger(OracleSchemaGenerator, ansisql.ANSISchemaChanger):
             column.server_default = sa.PassiveDefault(sa.sql.null())
         if notnull_hack:
             column.nullable = True
-        colspec=self.get_column_specification(column,
-                                              override_nullable=null_hack)
+        colspec = self.get_column_specification(column,
+            override_nullable=null_hack)
         if null_hack:
             colspec += ' NULL'
         if notnull_hack:
@@ -76,9 +78,10 @@ class OracleSchemaChanger(OracleSchemaGenerator, ansisql.ANSISchemaChanger):
         if dropdefault_hack:
             column.server_default = None
 
-        self.start_alter_table(table_name)
-        self.append("MODIFY ")
+        self.start_alter_table(table)
+        self.append("MODIFY (")
         self.append(colspec)
+        self.append(")")
 
 
 class OracleConstraintCommon(object):
