@@ -7,18 +7,20 @@ class Error(Exception):
     """
     Changeset error.
     """
-    pass
 
 
 class NotSupportedError(Error):
     """
     Not supported error.
     """
-    pass
 
 
 class InvalidConstraintError(Error):
     """
     Invalid constraint error.
     """
-    pass
+
+class MigrateDeprecationWarning(DeprecationWarning):
+    """
+    Warning for deprecated features in Migrate
+    """
