@@ -4,12 +4,15 @@
 
 import os
 import shutil
+import logging
 
 from migrate.versioning import exceptions
-from migrate.versioning.base import *
+from migrate.versioning.config import *
 from migrate.versioning.util import KeyedInstance
 
 
+log = logging.getLogger(__name__)
+
 class Pathed(KeyedInstance):
     """
     A class associated with a path/directory tree.
@@ -32,7 +35,7 @@ class Pathed(KeyedInstance):
         """Try to initialize this object's parent, if it has one"""
         parent_path = self.__class__._parent_path(path)
         self.parent = self.__class__.parent(parent_path)
-        log.info("Getting parent %r:%r" % (self.__class__.parent, parent_path))
+        log.debug("Getting parent %r:%r" % (self.__class__.parent, parent_path))
         self.parent._init_child(path, self)
 
     def _init_child(self, child, path):
@@ -52,7 +55,7 @@ class Pathed(KeyedInstance):
         #
         # Treat directories like files...
         if path[-1] == '/':
-            path=path[:-1]
+            path = path[:-1]
         ret = os.path.dirname(path)
         return ret
 
