@@ -1,11 +1,16 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+
 """The migrate command-line tool."""
 
 import sys
 import inspect
+import logging
 from optparse import OptionParser, BadOptionError
 
-from migrate.versioning.base import *
 from migrate.versioning import api, exceptions
+from migrate.versioning.config import *
+from migrate.versioning.util import asbool
 
 
 alias = dict(
@@ -17,8 +22,8 @@ alias = dict(
 
 def alias_setup():
     global alias
-    for key,val in alias.iteritems():
-        setattr(api,key,val)
+    for key, val in alias.iteritems():
+        setattr(api, key, val)
 alias_setup()
 
 
@@ -33,7 +38,8 @@ class PassiveOptionParser(OptionParser):
                 del rargs[0]
                 return
             elif arg[0:2] == "--":
-                # if parser does not know about the option, pass it along (make it anonymous)
+                # if parser does not know about the option
+                # pass it along (make it anonymous)
                 try:
                     opt = arg.split('=', 1)[0]
                     self._match_long_opt(opt)
@@ -49,24 +55,37 @@ class PassiveOptionParser(OptionParser):
                 del rargs[0]
 
 def main(argv=None, **kwargs):
-    """kwargs are default options that can be overriden with passing --some_option to cmdline"""
+    """Shell interface to :mod:`migrate.versioning.api`.
 
+    kwargs are default options that can be overriden with passing
+    --some_option as command line option
+
+    :param disable_logging: Let migrate configure logging
+    :type disable_logging: bool
+    """
     argv = argv or list(sys.argv[1:])
     commands = list(api.__all__)
     commands.sort()
 
-    usage="""%%prog COMMAND ...
+    usage = """%%prog COMMAND ...
 
     Available commands:
         %s
 
     Enter "%%prog help COMMAND" for information on a particular command.
-    """ % '\n\t'.join(commands)
+    """ % '\n\t'.join(["%s - %s" % (command.ljust(28), api.command_desc.get(command)) for command in commands])
 
     parser = PassiveOptionParser(usage=usage)
-    parser.add_option("-v", "--verbose", action="store_true", dest="verbose")
-    parser.add_option("-d", "--debug", action="store_true", dest="debug")
-    parser.add_option("-f", "--force", action="store_true", dest="force")
+    parser.add_option("-d", "--debug",
+                     action="store_true",
+                     dest="debug",
+                     default=False,
+                     help="Shortcut to turn on DEBUG mode for logging")
+    parser.add_option("-q", "--disable_logging",
+                      action="store_true",
+                      dest="disable_logging",
+                      default=False,
+                      help="Use this option to disable logging configuration")
     help_commands = ['help', '-h', '--help']
     HELP = False
 
@@ -129,12 +148,45 @@ def main(argv=None, **kwargs):
         try:
             kw = f_required.pop(0)
         except IndexError:
-            parser.error("Too many arguments for command %s: %s" % (command, arg))
+            parser.error("Too many arguments for command %s: %s" % (command,
+                                                                    arg))
         kwargs[kw] = arg
 
     # apply overrides
     kwargs.update(override_kwargs)
 
+    # configure options
+    for key, value in options.__dict__.iteritems():
+        kwargs.setdefault(key, value)
+
+    # configure logging
+    if not asbool(kwargs.pop('disable_logging', False)):
+        # filter to log =< INFO into stdout and rest to stderr
+        class SingleLevelFilter(logging.Filter):
+            def __init__(self, min=None, max=None):
+                self.min = min or 0
+                self.max = max or 100
+
+            def filter(self, record):
+                return self.min <= record.levelno <= self.max
+
+        logger = logging.getLogger()
+        h1 = logging.StreamHandler(sys.stdout)
+        f1 = SingleLevelFilter(max=logging.INFO)
+        h1.addFilter(f1)
+        h2 = logging.StreamHandler(sys.stderr)
+        f2 = SingleLevelFilter(min=logging.WARN)
+        h2.addFilter(f2)
+        logger.addHandler(h1)
+        logger.addHandler(h2)
+
+        if options.debug:
+            logger.setLevel(logging.DEBUG)
+        else:
+            logger.setLevel(logging.INFO)
+
+    log = logging.getLogger(__name__)
+
     # check if all args are given
     try:
         num_defaults = len(f_defaults)
@@ -143,16 +195,15 @@ def main(argv=None, **kwargs):
     f_args_default = f_args[len(f_args) - num_defaults:]
     required = list(set(f_required) - set(f_args_default))
     if required:
-        parser.error("Not enough arguments for command %s: %s not specified" % (command, ', '.join(required)))
+        parser.error("Not enough arguments for command %s: %s not specified" \
+            % (command, ', '.join(required)))
 
     # handle command
     try:
         ret = command_func(**kwargs)
         if ret is not None:
-            print ret
+            log.info(ret)
     except (exceptions.UsageError, exceptions.KnownError), e:
-        if e.args[0] is None:
-            parser.print_help()
         parser.error(e.args[0])
 
 if __name__ == "__main__":
